/**
 * Author: Niels Tsang
 * Date: 2011/07/13
 * 
 * SPOJ 8952 - Catapult that ball (Problem code: THRBL)
 * Problem Type: RMQ (Range Maximum Query)
 * http://www.spoj.pl/problems/THRBL/
 */

#include <algorithm>
#include <cmath>
#include <iostream>
using namespace std;

int N;
int H[50001];
int rMax[50001][16];  // 2^15 < 50000 < 2^16
// rMax[a][b]: H a _IA׬ 2^b  ranged maximum value

void initRMQ() {
    for( int i=1; i<=N; ++i ) {
        rMax[i][0] = H[i];
    }
    int logN = (int)( log( (double)N ) / log( 2.0 ) );
    for( int i=1; i<=logN; ++i ) {
        int pow2i = 1 << (i-1);
        for( int j=N; j>=1; --j ) {
            rMax[j][i] = rMax[j][i-1];
            if( j + pow2i <= N ) {
                rMax[j][i] = max( rMax[j][i], rMax[j+pow2i][i-1] );
            }
        }
    }
}

int RMQ( int lower, int upper ) {
    //int range = upper - lower + 1;
    int range = upper - lower;  // Important: Do NOT include B (upper)!!
    int logR = (int)( log( (double)(range) ) / log( 2.0 ) );
    int pow2logR = 1 << logR;
    //int lower2 = upper - pow2logR + 1;
    int lower2 = upper - pow2logR;  // Important: Do NOT include B (upper)!!
    int maxValue = max( rMax[lower][logR], rMax[lower2][logR] );
    return( maxValue );
}

int main() {
    int M;
    while( cin >> N >> M ) {
        for( int i=1; i<=N; ++i ) {
            cin >> H[i];
        }
        initRMQ();
        int cnt = 0;
        for( int i=0; i<M; ++i ) {
            int A, B;
            cin >> A >> B;
            int minAB = min( A, B );
            int maxAB = max( A, B );
            if( H[A] >= RMQ( minAB, maxAB ) ) {
                ++cnt;
            }
        }
        cout << cnt << endl;
    }
    return( 0 );
}
